audb.info
==========

.. automodule:: audb.info

author
------

.. autofunction:: author

bit_depths
----------

.. autofunction:: bit_depths

channels
--------

.. autofunction:: channels

description
-----------

.. autofunction:: description

duration
--------

.. autofunction:: duration

formats
-------

.. autofunction:: formats

header
------

.. autofunction:: header

languages
---------

.. autofunction:: languages

license
-------

.. autofunction:: license

license_url
-----------

.. autofunction:: license_url

media
-----

.. autofunction:: media

meta
----

.. autofunction:: meta

organization
------------

.. autofunction:: organization

raters
------

.. autofunction:: raters

sampling_rates
--------------

.. autofunction:: sampling_rates

schemes
-------

.. autofunction:: schemes

source
------

.. autofunction:: source

splits
------

.. autofunction:: splits

tables
------

.. autofunction:: tables

usage
-----

.. autofunction:: usage
